
RVBMain = {}
local RVBMain_mt = Class(RVBMain)

RVBMain.alertmessage = true
RVBMain.difficulty = 2
RVBMain.basicrepairtrigger = true
RVBMain.repairshop = true
RVBMain.debugdisplay = false
RVBMain.showtempdisplay = false
RVBMain.showrpmdisplay = false
RVBMain.dailyServiceInterval = 6
RVBMain.periodicServiceInterval = 40
RVBMain.workshopOpen = 7
RVBMain.workshopClose = 16

RVBMain.cp_notice = false

RVBMain.thermostatLifetime = 150
RVBMain.lightingsLifetime = 220
RVBMain.glowplugLifetime = 2
RVBMain.wipersLifetime = 80
RVBMain.generatorLifetime = 180
RVBMain.engineLifetime = 210
RVBMain.selfstarterLifetime = 3
RVBMain.batteryLifetime = 140
RVBMain.tireLifetime = 340
	
RVBMain.DEFAULT_SETTINGS = {
	alertmessage = RVBMain.alertmessage,
	difficulty = RVBMain.difficulty,
	basicrepairtrigger = RVBMain.basicrepairtrigger,
	debugdisplay = RVBMain.debugdisplay,
	showtempdisplay = RVBMain.showtempdisplay,
	showrpmdisplay = RVBMain.showrpmdisplay,
	repairshop = RVBMain.repairshop,
	dailyServiceInterval = RVBMain.dailyServiceInterval,
	periodicServiceInterval = RVBMain.periodicServiceInterval,
	workshopOpen = RVBMain.workshopOpen,
	workshopClose = RVBMain.workshopClose,
	cp_notice = RVBMain.cp_notice,
	thermostatLifetime = RVBMain.thermostatLifetime,
	lightingsLifetime = RVBMain.lightingsLifetime,
	glowplugLifetime = RVBMain.glowplugLifetime,
	wipersLifetime = RVBMain.wipersLifetime,
	generatorLifetime = RVBMain.generatorLifetime,
	engineLifetime = RVBMain.engineLifetime,
	selfstarterLifetime = RVBMain.selfstarterLifetime,
	batteryLifetime = RVBMain.batteryLifetime,
	tireLifetime = RVBMain.tireLifetime
}

local popupMessage

function RVBMain:new(modDirectory, modName)
	local self = {}
	setmetatable(self, RVBMain_mt)

	self.modDirectory = modDirectory
	self.modName = modName
	
	self.gameplaySettings = {}
	self.generalSettings = {}
	self.actionEvents = {}

	return self
end

function RVBMain:onMissionLoaded(mission)
		
	self:registerGamePlaySettingsSchema()
	self:registerGeneralSettingsSchema()

	self.mission = mission
	
	-- game play settings
	local DEFAUL_GAMEPLAY_SETTINGS_XML = Utils.getFilename("config/DefaultGamePlaySettings.xml", self.modDirectory)
	
	local savegameFolderPath = self.mission.missionInfo.savegameDirectory
	if savegameFolderPath == nil then
		savegameFolderPath = ('%ssavegame%d'):format(getUserProfileAppPath(), math.floor(self.mission.missionInfo.savegameIndex))
	end
	
	local GAMEPLAY_SETTINGS_XML = Utils.getFilename("/RVBGamePlaySettings.xml", savegameFolderPath)

	if fileExists(GAMEPLAY_SETTINGS_XML) then
		self:loadGamePlaySettingsFromXml(GAMEPLAY_SETTINGS_XML)
	else
		copyFile(DEFAUL_GAMEPLAY_SETTINGS_XML, GAMEPLAY_SETTINGS_XML, false)
		self:resetGamePlaySettings()
	end
	
	-- general settings
	local VEHICLE_BREAKDOWN_FOLDER = getUserProfileAppPath() .. "modSettings/FS25_gameplay_Real_Vehicle_Breakdowns/"
	createFolder(VEHICLE_BREAKDOWN_FOLDER)
	
	local GENERAL_SETTINGS_XML = Utils.getFilename("RVBGeneralSettings.xml", VEHICLE_BREAKDOWN_FOLDER)
	local DEFAUL_GENERAL_SETTINGS_XML = Utils.getFilename("config/DefaultGeneralSettings.xml", self.modDirectory)

	if fileExists(GENERAL_SETTINGS_XML) then
		self:loadGeneralSettingsFromXml(GENERAL_SETTINGS_XML)
	else
		copyFile(DEFAUL_GENERAL_SETTINGS_XML, GENERAL_SETTINGS_XML, false)
		self:resetGeneralSettings()
	end
	
	-- 
	g_RVBworkshopScreen = rvbWorkshopScreen.register()
	
	-- hud
	RVBMain.rvbHud = RVB_HUD.new()
    RVBMain.rvbHud:setScale(g_gameSettings:getValue(GameSettings.SETTING.UI_SCALE))
	RVBMain.rvbHud:setVehicle(nil)
	table.insert(mission.hud.displayComponents, RVBMain.rvbHud)
	mission.hud.setControlledVehicle = Utils.appendedFunction(mission.hud.setControlledVehicle, function(self, vehicle)
		RVBMain.rvbHud:setVehicle(vehicle)
		RVBMain.rvbHud:setVisible(vehicle ~= nil and vehicle.spec_motorized ~= nil, true)
	end)
	mission.hud.update = Utils.appendedFunction(mission.hud.update, function(self, dt)
		--RVBMain.rvbHud:update(dt)
	end)
	mission.hud.drawControlledEntityHUD = Utils.appendedFunction(mission.hud.drawControlledEntityHUD, function(self)
		if self.isVisible then
			RVBMain.rvbHud:draw()
		end
	end)
	
	self.menu = RVBMenu.register()
	self.menu:setServer(g_server)
	self.menu:setMissionInfo(self.mission.missionInfo, self.mission.missionDynamicInfo, self.modDirectory)

	local conflictList = {}
	if g_modIsLoaded["FS25_Courseplay"] then
		if FS25_Courseplay ~= nil and FS25_Courseplay.WearableController.autoRepair ~= nil then
			table.insert(conflictList, "CoursePlay")
			FS25_Courseplay.WearableController.autoRepair = Utils.overwrittenFunction(FS25_Courseplay.WearableController.autoRepair, RVBMain.autoRepair)
		end
	end

	if g_modIsLoaded["FS25_AutoDrive"] then
		if FS25_AutoDrive ~= nil and FS25_AutoDrive.ADTaskModule.hasToRepair ~= nil then
			table.insert(conflictList, "AutoDrive")
			FS25_AutoDrive.ADTaskModule.hasToRepair = Utils.overwrittenFunction(FS25_AutoDrive.ADTaskModule.hasToRepair, RVBMain.hasToRepair)
		end
	end

	if #conflictList > 0 then
		popupMessage = {
			startUpdateTime = 2000,
			update = function(self, dt)
				self.startUpdateTime = self.startUpdateTime - dt
				if self.startUpdateTime < 0 and not g_gui:getIsGuiVisible() then
					if g_currentMission.hud ~= nil then
						local message = tostring(g_i18n:getText("Automatic_Repair_conflict_notice") .."\n".. g_i18n:getText("Automatic_Repair_conflict_notice_b") .."\n".. g_i18n:getText("Automatic_Repair_conflict_list") .."\n"..
						table.concat(conflictList, ", ") .."\n"..	g_i18n:getText("Automatic_Repair_conflict_signature"))
						--g_gui:showInfoDialog({
						--	text = message
						--})
						--g_currentMission.hud:showInGameMessage("", message, -1, nil, nil, self)
					end
					removeModEventListener(self)
					popupMessage = nil
				end
			end
		}
		if not self.generalSettings.cp_notice then
			addModEventListener(popupMessage)
			self.generalSettings.cp_notice = true
			
			self:saveGeneralettingsToXML()
			if g_server ~= nil then
				--g_server:broadcastEvent(RVBGeneralSet_Event.new(self.generalSettings.alertmessage, self.generalSettings.difficulty, self.generalSettings.basicrepairtrigger, self.generalSettings.debugdisplay, self.generalSettings.cp_notice), nil, nil, self)
			else
				--g_client:getServerConnection():sendEvent(RVBGeneralSet_Event.new(self.generalSettings.alertmessage, self.generalSettings.difficulty, self.generalSettings.basicrepairtrigger, self.generalSettings.debugdisplay, self.generalSettings.cp_notice))
			end
		end
	end
	
	if g_modIsLoaded["FS25_ToolBoxPack"] then
		--if FS25_ToolBoxPack ~= nil and FS25_ToolBoxPack.ServiceVehicleWorkshop.openMenu ~= nil then
		--	FS25_ToolBoxPack.ServiceVehicleWorkshop.openMenu = Utils.overwrittenFunction(FS25_ToolBoxPack.ServiceVehicleWorkshop.openMenu, RVBMain.RVBopenMenu)
		--end
	end
	
	if g_modIsLoaded["FS25_lsfmFarmEquipmentPack"] then
		--if FS25_lsfmFarmEquipmentPack ~= nil and FS25_lsfmFarmEquipmentPack.ServiceVehicleWorkshop.openMenu ~= nil then
		--	FS25_lsfmFarmEquipmentPack.ServiceVehicleWorkshop.openMenu = Utils.overwrittenFunction(FS25_lsfmFarmEquipmentPack.ServiceVehicleWorkshop.openMenu, RVBMain.RVBopenMenu)
		--end
	end
	
	if g_currentMission.missionInfo.automaticMotorStartEnabled then
		g_currentMission:setAutomaticMotorStartEnabled(false, true)
	end

end

-- Original CP WearableController:autoRepair()
function RVBMain:autoRepair(superFunc)
	--if self:isBrokenGreaterThan(100-self.autoRepairSetting:getValue()) then 
	--	self.implement:repairVehicle()
	--end
end

-- Original AD ADTaskModule hasToRepair()
function RVBMain:hasToRepair()
	local repairNeeded = false
--	if self.vehicle.ad.onRouteToRepair then
--		repair is forced by user or CP, so send vehicle to workshop independent of damage level
--		return true
--	end
--	if AutoDrive.getSetting("autoRepair", self.vehicle) then
--		local attachedObjects = AutoDrive.getAllImplements(self.vehicle, true)
--		for _, attachedObject in pairs(attachedObjects) do
--			repairNeeded = repairNeeded or (attachedObject.spec_wearable ~= nil and attachedObject.spec_wearable.damage > 0.6)
--		end
--	end
	return repairNeeded
end


function RVBMain.installSpecializations(vehicleTypeManager, specializationManager, modDirectory, modName)
	specializationManager:addSpecialization("vehicleBreakdowns", "VehicleBreakdowns", Utils.getFilename("scripts/vehicles/specializations/VehicleBreakdowns.lua", modDirectory), nil)

	if specializationManager:getSpecializationByName("vehicleBreakdowns") == nil then
		Logging.error("[RVB] getSpecializationByName(\"vehicleBreakdowns\") == nil")
	else
		for typeName, typeEntry in pairs(vehicleTypeManager:getTypes()) do
			
			if typeEntry ~= nil and typeName ~= "locomotive" and typeName ~= "trainTrailer" and typeName ~= "trainTimberTrailer" and typeName ~= "conveyorBelt" and typeName ~= "pickupConveyorBelt" 
			and typeName ~= "highPressureWasher" and typeName ~= "FS25_lsfmFarmEquipmentPack.wheelBarrow" and typeName ~= "FS25_lsfmFarmEquipmentPack.wheelBarrowHay" 
			and typeName ~= "FS25_lsfmFarmEquipmentPack.bicycle" and typeName ~= "FS25_lsfmFarmEquipmentPack.transportBarrow" and typeName ~= "FS25_lsfmFarmEquipmentPack.milkShuttle"
			and typeName ~= "FS25_lsfmFarmEquipmentPack.transportBarrowBarrel" and typeName ~= "FS25_lsfmFarmEquipmentPack.transportBarrelModul" and typeName ~= "FS25_Wheelbarrow.handTool"
			and typeName ~= "FS25_talicska.wheelBarrow" then -- portableToolbox
				if SpecializationUtil.hasSpecialization(Drivable, typeEntry.specializations) and
					SpecializationUtil.hasSpecialization(Enterable, typeEntry.specializations) and
					SpecializationUtil.hasSpecialization(Motorized, typeEntry.specializations) and
					not SpecializationUtil.hasSpecialization(VehicleBreakdowns, typeEntry.specializations) then
						vehicleTypeManager:addSpecialization(typeName, modName .. ".vehicleBreakdowns")
						print("  Register RVB \'" ..typeName .. "\'")
				end
			else
				Logging.info("  No register RVB \'" .. typeName .. "\'")
			end
			
		end
	end
end

function RVBMain:registerGamePlaySettingsSchema()

	self.gameplaySettingSchema = XMLSchema.new("rvbGamePlaySettings")
	local schemaKey = "rvbGamePlaySettings"
	
	self.gameplaySettingSchema:register(XMLValueType.INT, schemaKey .. ".dailyServiceInterval#value", "Daily Service Interval")
	self.gameplaySettingSchema:register(XMLValueType.INT, schemaKey .. ".periodicServiceInterval#value", "Periodic Service Interval")
	self.gameplaySettingSchema:register(XMLValueType.BOOL, schemaKey .. ".repairshop#value", "Repair only in vehicle workshop")
	self.gameplaySettingSchema:register(XMLValueType.INT, schemaKey .. ".workshopOpen#value", "Workshop opening")
	self.gameplaySettingSchema:register(XMLValueType.INT, schemaKey .. ".workshopClose#value", "Workshop closing")
	self.gameplaySettingSchema:register(XMLValueType.INT, schemaKey .. ".thermostatLifetime#value", "Thermostat Lifetime")
	self.gameplaySettingSchema:register(XMLValueType.INT, schemaKey .. ".lightingsLifetime#value", "Lightings Lifetime")
	self.gameplaySettingSchema:register(XMLValueType.INT, schemaKey .. ".glowplugLifetime#value", "Glowplug Lifetime")
	self.gameplaySettingSchema:register(XMLValueType.INT, schemaKey .. ".wipersLifetime#value", "Wipers Lifetime")
	self.gameplaySettingSchema:register(XMLValueType.INT, schemaKey .. ".generatorLifetime#value", "Generator Lifetime")
	self.gameplaySettingSchema:register(XMLValueType.INT, schemaKey .. ".engineLifetime#value", "Engine Lifetime")
	self.gameplaySettingSchema:register(XMLValueType.INT, schemaKey .. ".selfstarterLifetime#value", "Selfstarter Lifetime")
	self.gameplaySettingSchema:register(XMLValueType.INT, schemaKey .. ".batteryLifetime#value", "Battery Lifetime")
	self.gameplaySettingSchema:register(XMLValueType.INT, schemaKey .. ".tireLifetime#value", "Tire Lifetime")

end
	
function RVBMain:registerGeneralSettingsSchema()
	
	self.generalSettingSchema = XMLSchema.new("rvbGeneralSettings")
	local schemaKey = "rvbGeneralSettings"
	
	self.generalSettingSchema:register(XMLValueType.BOOL, schemaKey .. ".alertmessage#value", "Alert Message")
	self.generalSettingSchema:register(XMLValueType.INT, schemaKey .. ".difficulty#value", "RVB difficulty")
	self.generalSettingSchema:register(XMLValueType.BOOL, schemaKey .. ".basicrepairtrigger#value", "")
	self.generalSettingSchema:register(XMLValueType.BOOL, schemaKey .. ".debugdisplay#value", "debugdisplay")
	self.generalSettingSchema:register(XMLValueType.BOOL, schemaKey .. ".showtempdisplay#value", "showtempdisplay")
	self.generalSettingSchema:register(XMLValueType.BOOL, schemaKey .. ".showrpmdisplay#value", "showrpmdisplay")
	self.generalSettingSchema:register(XMLValueType.BOOL, schemaKey .. ".cp_notice#value", "CP")

end

function RVBMain:loadGamePlaySettingsFromXml(xmlPath)
	local xmlFile = XMLFile.load("configXml", xmlPath, self.gameplaySettingSchema)

	if xmlFile ~= 0 then

		local key = "rvbGamePlaySettings"
		
		self.gameplaySettings.repairshop              = xmlFile:getValue(key .. ".repairshop#value", RVBMain.repairshop)
		self.gameplaySettings.dailyServiceInterval    = xmlFile:getValue(key .. ".dailyServiceInterval#value", RVBMain.dailyServiceInterval)
		self.gameplaySettings.periodicServiceInterval = xmlFile:getValue(key .. ".periodicServiceInterval#value", RVBMain.periodicServiceInterval)
		self.gameplaySettings.workshopOpen            = xmlFile:getValue(key .. ".workshopOpen#value", RVBMain.workshopOpen)
		self.gameplaySettings.workshopClose           = xmlFile:getValue(key .. ".workshopClose#value", RVBMain.workshopClose)
		self.gameplaySettings.thermostatLifetime      = xmlFile:getValue(key .. ".thermostatLifetime#value", RVBMain.thermostatLifetime)
		self.gameplaySettings.lightingsLifetime       = xmlFile:getValue(key .. ".lightingsLifetime#value", RVBMain.lightingsLifetime)
		self.gameplaySettings.glowplugLifetime        = xmlFile:getValue(key .. ".glowplugLifetime#value", RVBMain.glowplugLifetime)
		self.gameplaySettings.wipersLifetime          = xmlFile:getValue(key .. ".wipersLifetime#value", RVBMain.wipersLifetime)
		self.gameplaySettings.generatorLifetime       = xmlFile:getValue(key .. ".generatorLifetime#value", RVBMain.generatorLifetime)
		self.gameplaySettings.engineLifetime          = xmlFile:getValue(key .. ".engineLifetime#value", RVBMain.engineLifetime)
		self.gameplaySettings.selfstarterLifetime     = xmlFile:getValue(key .. ".selfstarterLifetime#value", RVBMain.selfstarterLifetime)
		self.gameplaySettings.batteryLifetime         = xmlFile:getValue(key .. ".batteryLifetime#value", RVBMain.batteryLifetime)
		self.gameplaySettings.tireLifetime            = xmlFile:getValue(key .. ".tireLifetime#value", RVBMain.tireLifetime)

		xmlFile:delete()
	end
end

function RVBMain:loadGeneralSettingsFromXml(xmlPath)
	local xmlFile = XMLFile.load("configXml", xmlPath, self.generalSettingSchema)

	if xmlFile ~= 0 then

		local key = "rvbGeneralSettings"

		self.generalSettings.alertmessage       = xmlFile:getValue(key .. ".alertmessage#value", RVBMain.alertmessage)
		self.generalSettings.difficulty         = xmlFile:getValue(key .. ".difficulty#value", RVBMain.difficulty)
		self.generalSettings.basicrepairtrigger = xmlFile:getValue(key .. ".basicrepairtrigger#value", RVBMain.basicrepairtrigger)
		self.generalSettings.debugdisplay       = xmlFile:getValue(key .. ".debugdisplay#value", RVBMain.debugdisplay)
		self.generalSettings.showtempdisplay    = xmlFile:getValue(key .. ".showtempdisplay#value", RVBMain.showtempdisplay)
		self.generalSettings.showrpmdisplay     = xmlFile:getValue(key .. ".showrpmdisplay#value", RVBMain.showrpmdisplay)
		self.generalSettings.cp_notice          = xmlFile:getValue(key .. ".cp_notice#value", RVBMain.cp_notice)
		
		xmlFile:delete()
	end
end

function RVBMain:resetGamePlaySettings()
	self.gameplaySettings = {
		repairshop = RVBMain.DEFAULT_SETTINGS.repairshop,
		dailyServiceInterval = RVBMain.DEFAULT_SETTINGS.dailyServiceInterval,
		periodicServiceInterval = RVBMain.DEFAULT_SETTINGS.periodicServiceInterval,
		workshopOpen = RVBMain.DEFAULT_SETTINGS.workshopOpen,
		workshopClose = RVBMain.DEFAULT_SETTINGS.workshopClose,
		thermostatLifetime = RVBMain.DEFAULT_SETTINGS.thermostatLifetime,
		lightingsLifetime = RVBMain.DEFAULT_SETTINGS.lightingsLifetime,
		glowplugLifetime = RVBMain.DEFAULT_SETTINGS.glowplugLifetime,
		wipersLifetime = RVBMain.DEFAULT_SETTINGS.wipersLifetime,
		generatorLifetime = RVBMain.DEFAULT_SETTINGS.generatorLifetime,
		engineLifetime = RVBMain.DEFAULT_SETTINGS.engineLifetime,
		selfstarterLifetime = RVBMain.DEFAULT_SETTINGS.selfstarterLifetime,
		batteryLifetime = RVBMain.DEFAULT_SETTINGS.batteryLifetime,
		tireLifetime = RVBMain.DEFAULT_SETTINGS.tireLifetime
	}
end

function RVBMain:resetGeneralSettings()
	self.generalSettings = {
		alertmessage = RVBMain.DEFAULT_SETTINGS.alertmessage,
		difficulty = RVBMain.DEFAULT_SETTINGS.difficulty,
		basicrepairtrigger = RVBMain.DEFAULT_SETTINGS.basicrepairtrigger,
		debugdisplay = RVBMain.DEFAULT_SETTINGS.debugdisplay,
		showtempdisplay = RVBMain.DEFAULT_SETTINGS.showtempdisplay,
		showrpmdisplay = RVBMain.DEFAULT_SETTINGS.showrpmdisplay,
		cp_notice = RVBMain.DEFAULT_SETTINGS.cp_notice
	}
end

function RVBMain:RVBopenMenu(superFunc)
	local vehicles = self:determineCurrentVehicles()
	g_RVBworkshopScreen:setSellingPoint(self, not self.ownWorkshop, self.ownWorkshop, self.mobileWorkshop)
	g_RVBworkshopScreen:setVehicles(vehicles)
	g_gui:showGui("rvbWorkshopScreen")
end
VehicleSellingPoint.openMenu = Utils.overwrittenFunction(VehicleSellingPoint.openMenu, RVBMain.RVBopenMenu)

function RVBMain:RVBsellAreaTriggerCallback(superFunc, _, _, onEnter, onLeave, _, otherShapeId)
	if otherShapeId ~= nil and (onEnter or onLeave) then
		if onEnter then
			self.vehicleShapesInRange[otherShapeId] = true
		elseif onLeave then
			self.vehicleShapesInRange[otherShapeId] = nil
		end
		g_RVBworkshopScreen:updateVehicles(self, self:determineCurrentVehicles())
	end
end
VehicleSellingPoint.sellAreaTriggerCallback = Utils.overwrittenFunction(VehicleSellingPoint.sellAreaTriggerCallback, RVBMain.RVBsellAreaTriggerCallback)


function RVBMain:setCustomGamePlaySet(dailyServiceInterval, periodicServiceInterval, repairshop, workshopOpen, workshopClose, thermostatLifetime, lightingsLifetime,
	glowplugLifetime, wipersLifetime, generatorLifetime, engineLifetime, selfstarterLifetime, batteryLifetime, tireLifetime)

	if g_server then

		g_server:broadcastEvent(RVBGamePSet_Event.new(dailyServiceInterval, periodicServiceInterval, repairshop, workshopOpen, workshopClose, thermostatLifetime, lightingsLifetime,
		glowplugLifetime, wipersLifetime, generatorLifetime, engineLifetime, selfstarterLifetime, batteryLifetime, tireLifetime))

		self:setIsDailyServiceInterval(dailyServiceInterval)
		self:setPeriodicServiceInterval(periodicServiceInterval)
		self:setIsRepairShop(repairshop)
		self:setWorkshopOpen(workshopOpen)
		self:setWorkshopClose(workshopClose)
		self:setThermostatLifetime(thermostatLifetime)
		self:setLightingsLifetime(lightingsLifetime)
		self:setGlowplugLifetime(glowplugLifetime)
		self:setWipersLifetime(wipersLifetime)
		self:setGeneratorLifetime(generatorLifetime)
		self:setEngineLifetime(engineLifetime)
		self:setSelfstarterLifetime(selfstarterLifetime)
		self:setBatteryLifetime(batteryLifetime)
		self:setTireLifetime(tireLifetime)

	end

end

function RVBMain:setCustomGeneralSet(alertmessage, difficulty, basicrepairtrigger, debugdisplay, showtempdisplay, showrpmdisplay, cp_notice)

	if g_server then

		g_server:broadcastEvent(RVBGeneralSet_Event.new(alertmessage, difficulty, basicrepairtrigger, debugdisplay, showtempdisplay, showrpmdisplay, cp_notice), nil, nil, self)

		self:setIsAlertMessage(alertmessage)
		self:setRVBDifficulty(difficulty)
		self:setIsBasicRepairTrigger(basicrepairtrigger)
		self:setIsDebugDisplay(debugdisplay)
		self:setIsShowTempDisplay(showtempdisplay)
		self:setIsShowRpmDisplay(showrpmdisplay)
		self:setIsCPNotice(cp_notice)

	end

end

function RVBMain:rvbsaveToXMLFile(RVBXMLFile)

	local schemaKey = "rvbGamePlaySettings"
	local xmlFile = XMLFile.create("RBVGamePlaySettingsXML", RVBXMLFile, "rvbGamePlaySettings", self.gameplaySettingSchema)
	if xmlFile == 0 then
        print("Hiba: Nem sikerült létrehozni az XML fájlt!")
        return
    end
	if xmlFile ~= 0 then
		xmlFile:setValue(schemaKey .. ".dailyServiceInterval#value", self.gameplaySettings.dailyServiceInterval)
		xmlFile:setValue(schemaKey .. ".periodicServiceInterval#value", self.gameplaySettings.periodicServiceInterval)
		xmlFile:setValue(schemaKey .. ".repairshop#value", self.gameplaySettings.repairshop)
		xmlFile:setValue(schemaKey .. ".workshopOpen#value", self.gameplaySettings.workshopOpen)
		xmlFile:setValue(schemaKey .. ".workshopClose#value", self.gameplaySettings.workshopClose)
		xmlFile:setValue(schemaKey .. ".thermostatLifetime#value", self.gameplaySettings.thermostatLifetime)
		xmlFile:setValue(schemaKey .. ".lightingsLifetime#value", self.gameplaySettings.lightingsLifetime)
		xmlFile:setValue(schemaKey .. ".glowplugLifetime#value", self.gameplaySettings.glowplugLifetime)
		xmlFile:setValue(schemaKey .. ".wipersLifetime#value", self.gameplaySettings.wipersLifetime)
		xmlFile:setValue(schemaKey .. ".generatorLifetime#value", self.gameplaySettings.generatorLifetime)
		xmlFile:setValue(schemaKey .. ".engineLifetime#value", self.gameplaySettings.engineLifetime)
		xmlFile:setValue(schemaKey .. ".selfstarterLifetime#value", self.gameplaySettings.selfstarterLifetime)
		xmlFile:setValue(schemaKey .. ".batteryLifetime#value", self.gameplaySettings.batteryLifetime)
		xmlFile:setValue(schemaKey .. ".tireLifetime#value", self.gameplaySettings.tireLifetime)
		xmlFile:save()
		xmlFile:delete()
	end
		
end

function RVBMain:saveGeneralettingsToXML()

	local VEHICLE_BREAKDOWN_FOLDER = getUserProfileAppPath() .. "modSettings/FS25_gameplay_Real_Vehicle_Breakdowns/"
	local GENERAL_SETTINGS_XML = Utils.getFilename("RVBGeneralSettings.xml", VEHICLE_BREAKDOWN_FOLDER)
	local schemaKey = "rvbGeneralSettings"
	local xmlFile = XMLFile.create("RBVGeneralSettingsXML", GENERAL_SETTINGS_XML, "rvbGeneralSettings", self.generalSettingSchema)
	if xmlFile ~= 0 then
		xmlFile:setValue(schemaKey .. ".alertmessage#value", self.generalSettings.alertmessage)
		xmlFile:setValue(schemaKey .. ".difficulty#value", self.generalSettings.difficulty)
		xmlFile:setValue(schemaKey .. ".basicrepairtrigger#value", self.generalSettings.basicrepairtrigger)
		xmlFile:setValue(schemaKey .. ".debugdisplay#value", self.generalSettings.debugdisplay)
		xmlFile:setValue(schemaKey .. ".showtempdisplay#value", self.generalSettings.showtempdisplay)
		xmlFile:setValue(schemaKey .. ".showrpmdisplay#value", self.generalSettings.showrpmdisplay)
		xmlFile:setValue(schemaKey .. ".cp_notice#value", self.generalSettings.cp_notice)
		xmlFile:save()
		xmlFile:delete()
	end
	
end

function RVBMain:update()
end

function RVBMain:draw()
end

function RVBMain:delete()
end

function RVBMain:getIsAlertMessage()
	return self.generalSettings.alertmessage
end

function RVBMain:setIsAlertMessage(alertmessage, noEventSend)
	if alertmessage ~= self.generalSettings.alertmessage then
		self.generalSettings.alertmessage = alertmessage
		self:saveGeneralettingsToXML()
		--SavegameSettingsEvent.sendEvent(noEventSend)
		Logging.info("[RVB] Settings \'alertmessage\': %s", alertmessage)
	end
end

function RVBMain:getRVBDifficulty()
	return self.generalSettings.difficulty
end

function RVBMain:setRVBDifficulty(difficulty, noEventSend)
	if difficulty ~= self.generalSettings.difficulty then
		self.generalSettings.difficulty = difficulty
		self:saveGeneralettingsToXML()
		--SavegameSettingsEvent.sendEvent(noEventSend)
		local difficultyTable = {}
		table.insert(difficultyTable, g_i18n:getText("RVB_difficulty_slow"))
		table.insert(difficultyTable, g_i18n:getText("RVB_difficulty_medium"))
		table.insert(difficultyTable, g_i18n:getText("RVB_difficulty_fast"))
		Logging.info("[RVB] Settings \'difficulty\': %s", difficultyTable[difficulty])
	end
end

function RVBMain:getIsBasicRepairTrigger()
	return self.generalSettings.basicrepairtrigger
end

function RVBMain:setIsBasicRepairTrigger(basicrepairtrigger, noEventSend)
	if basicrepairtrigger ~= self.generalSettings.basicrepairtrigger then
		self.generalSettings.basicrepairtrigger = basicrepairtrigger
		self:saveGeneralettingsToXML()
		--SavegameSettingsEvent.sendEvent(noEventSend)
		Logging.info("[RVB] Settings \'basicrepairtrigger\': %s", basicrepairtrigger)
	end
end

function RVBMain:getIsDebugDisplay()
	return self.generalSettings.debugdisplay
end

function RVBMain:setIsDebugDisplay(debugdisplay, noEventSend)
	if debugdisplay ~= self.generalSettings.debugdisplay then
		self.generalSettings.debugdisplay = debugdisplay
		self:saveGeneralettingsToXML()
		--SavegameSettingsEvent.sendEvent(noEventSend)
		Logging.info("[RVB] Settings \'debugdisplay\': %s", debugdisplay)
	end
end

function RVBMain:getIsShowTempDisplay()
	return self.generalSettings.showtempdisplay
end

function RVBMain:setIsShowTempDisplay(showtempdisplay, noEventSend)
	if showtempdisplay ~= self.generalSettings.showtempdisplay then
		self.generalSettings.showtempdisplay = showtempdisplay
		self:saveGeneralettingsToXML()
		--SavegameSettingsEvent.sendEvent(noEventSend)
		Logging.info("[RVB] Settings \'showtempdisplay\': %s", showtempdisplay)
	end
end

function RVBMain:getIsShowRpmDisplay()
	return self.generalSettings.showrpmdisplay
end

function RVBMain:setIsShowRpmDisplay(showrpmdisplay, noEventSend)
	if showrpmdisplay ~= self.generalSettings.showrpmdisplay then
		self.generalSettings.showrpmdisplay = showrpmdisplay
		self:saveGeneralettingsToXML()
		--SavegameSettingsEvent.sendEvent(noEventSend)
		Logging.info("[RVB] Settings \'showrpmdisplay\': %s", showrpmdisplay)
	end
end

function RVBMain:setIsCPNotice(cpnotice)
	self.generalSettings.cp_notice = cpnotice
end

--[[**************************************************]]

function RVBMain:getDailyService()
	return self.gameplaySettings.dailyServiceInterval
end

function RVBMain:setDailyServiceInterval(dailyServiceInterval)
	self.gameplaySettings.dailyServiceInterval = dailyServiceInterval
end

function RVBMain:getPeriodicService()
	return self.gameplaySettings.periodicServiceInterval
end

function RVBMain:setPeriodicServiceInterval(periodicServiceInterval, noEventSend)
	if periodicServiceInterval ~= self.gameplaySettings.periodicServiceInterval then
		self.gameplaySettings.periodicServiceInterval = periodicServiceInterval
		--SavegameSettingsEvent.sendEvent(noEventSend)
		Logging.info("[RVB] Settings \'periodicServiceInterval\': %s", periodicServiceInterval)
	end
end

function RVBMain:getIsRepairShop()
	return self.gameplaySettings.repairshop
end

function RVBMain:setIsRepairShop(repairshop, noEventSend)
	if repairshop ~= self.gameplaySettings.repairshop then
		self.gameplaySettings.repairshop = repairshop
		--SavegameSettingsEvent.sendEvent(noEventSend)
		Logging.info("[RVB] Settings \'repairshop\': %s", tostring(repairshop))
	end
end

function RVBMain:getWorkshopOpen()
	return self.gameplaySettings.workshopOpen
end

function RVBMain:setWorkshopOpen(workshopOpen, noEventSend)
	if workshopOpen ~= self.gameplaySettings.workshopOpen then
		self.gameplaySettings.workshopOpen = workshopOpen
		--SavegameSettingsEvent.sendEvent(noEventSend)
		Logging.info("[RVB] Settings \'workshopOpen\': %s", workshopOpen)
	end
end

function RVBMain:getWorkshopClose()
	return self.gameplaySettings.workshopClose
end

function RVBMain:setWorkshopClose(workshopClose, noEventSend)
	if workshopClose ~= self.gameplaySettings.workshopClose then
		self.gameplaySettings.workshopClose = workshopClose
		--SavegameSettingsEvent.sendEvent(noEventSend)
		Logging.info("[RVB] Settings \'workshopClose\': %s", workshopClose)
	end
end

function RVBMain:getThermostatLifetime()
	return self.gameplaySettings.thermostatLifetime
end

function RVBMain:setThermostatLifetime(thermostat, noEventSend)
	thermostat = math.clamp(thermostat, rvb_Utils.LargeArrayMin, rvb_Utils.LargeArrayMax)
	if thermostat ~= self.gameplaySettings.thermostatLifetime then
		self.gameplaySettings.thermostatLifetime = thermostat
		--SavegameSettingsEvent.sendEvent(noEventSend)
		Logging.info("[RVB] Settings \'thermostatLifetime\': %s", thermostat)
	end
end

function RVBMain:getLightingsLifetime()
	return self.gameplaySettings.lightingsLifetime
end

function RVBMain:setLightingsLifetime(lightings, noEventSend)
	lightings = math.clamp(lightings, rvb_Utils.LargeArrayMin, rvb_Utils.LargeArrayMax)
	if lightings ~= self.gameplaySettings.lightingsLifetime then
		self.gameplaySettings.lightingsLifetime = lightings
		--SavegameSettingsEvent.sendEvent(noEventSend)
		Logging.info("[RVB] Settings \'lightingsLifetime\': %s", lightings)
	end
end

function RVBMain:getGlowplugLifetime()
	return self.gameplaySettings.glowplugLifetime
end

function RVBMain:setGlowplugLifetime(glowplug, noEventSend)
	glowplug = math.clamp(glowplug, rvb_Utils.SmallArrayMin, rvb_Utils.SmallArrayMax)
	if glowplug ~= self.gameplaySettings.glowplugLifetime then
		self.gameplaySettings.glowplugLifetime = glowplug
		--SavegameSettingsEvent.sendEvent(noEventSend)
		Logging.info("[RVB] Settings \'glowplugLifetime\': %s", glowplug)
	end
end

function RVBMain:getWipersLifetime()
	return self.gameplaySettings.wipersLifetime
end

function RVBMain:setWipersLifetime(wipers, noEventSend)
	wipers = math.clamp(wipers, rvb_Utils.LargeArrayMin, rvb_Utils.LargeArrayMax)
	if wipers ~= self.gameplaySettings.wipersLifetime then
		self.gameplaySettings.wipersLifetime = wipers
		--SavegameSettingsEvent.sendEvent(noEventSend)
		Logging.info("[RVB] Settings \'wipersLifetime\': %s", wipers)
	end
end

function RVBMain:getGeneratorLifetime()
	return self.gameplaySettings.generatorLifetime
end

function RVBMain:setGeneratorLifetime(generator, noEventSend)
	generator = math.clamp(generator, rvb_Utils.LargeArrayMin, rvb_Utils.LargeArrayMax)
	if generator ~= self.gameplaySettings.generatorLifetime then
		self.gameplaySettings.generatorLifetime = generator
		--SavegameSettingsEvent.sendEvent(noEventSend)
		Logging.info("[RVB] Settings \'generatorLifetime\': %s", generator)
	end
end

function RVBMain:getEngineLifetime()
	return self.gameplaySettings.engineLifetime
end

function RVBMain:setEngineLifetime(engine, noEventSend)
	engine = math.clamp(engine, rvb_Utils.LargeArrayMin, rvb_Utils.LargeArrayMax)
	if engine ~= self.gameplaySettings.engineLifetime then
		self.gameplaySettings.engineLifetime = engine
		--SavegameSettingsEvent.sendEvent(noEventSend)
		Logging.info("[RVB] Settings \'engineLifetime\': %s", engine)
	end
end

function RVBMain:getSelfstarterLifetime()
	return self.gameplaySettings.selfstarterLifetime
end

function RVBMain:setSelfstarterLifetime(selfstarter, noEventSend)
	selfstarter = math.clamp(selfstarter, rvb_Utils.SmallArrayMin, rvb_Utils.SmallArrayMax)
	if selfstarter ~= self.gameplaySettings.selfstarterLifetime then
		self.gameplaySettings.selfstarterLifetime = selfstarter
		--SavegameSettingsEvent.sendEvent(noEventSend)
		Logging.info("[RVB] Settings \'selfstarterLifetime\': %s", selfstarter)
	end
end

function RVBMain:getBatteryLifetime()
	return self.gameplaySettings.batteryLifetime
end

function RVBMain:setBatteryLifetime(battery, noEventSend)
	battery = math.clamp(battery, rvb_Utils.LargeArrayMin, rvb_Utils.LargeArrayMax)
	if battery ~= self.gameplaySettings.batteryLifetime then
		self.gameplaySettings.batteryLifetime = battery
		--SavegameSettingsEvent.sendEvent(noEventSend)
		Logging.info("[RVB] Settings \'batteryLifetime\': %s", battery)
	end
end

function RVBMain:getTireLifetime()
	return self.gameplaySettings.tireLifetime
end

function RVBMain:setTireLifetime(tire, noEventSend)
	tire = math.clamp(tire, rvb_Utils.LargeArrayMin, rvb_Utils.LargeArrayMax)
	if tire ~= self.gameplaySettings.tireLifetime then
		self.gameplaySettings.tireLifetime = tire
		--SavegameSettingsEvent.sendEvent(noEventSend)
		Logging.info("[RVB] Settings \'tireLifetime\': %s", tire)
	end
end

function RVBMain:syncSettingsToAllClients()
	local eventGPS = RVBGeneralSet_Event.new(self.gameplaySettings.dailyServiceInterval, self.gameplaySettings.periodicServiceInterval, 
                                          self.gameplaySettings.repairshop, self.gameplaySettings.workshopOpen, self.gameplaySettings.workshopClose,
										  self.gameplaySettings.thermostatLifetime, self.gameplaySettings.lightingsLifetime, self.gameplaySettings.glowplugLifetime,
										  self.gameplaySettings.wipersLifetime, self.gameplaySettings.generatorLifetime, self.gameplaySettings.engineLifetime,
										  self.gameplaySettings.selfstarterLifetime, self.gameplaySettings.batteryLifetime, self.gameplaySettings.tireLifetime)

    local eventGS = RVBGeneralSet_Event.new(self.generalSettings.alertmessage, self.generalSettings.difficulty, 
                                          self.generalSettings.basicrepairtrigger, self.generalSettings.debugdisplay, self.generalSettings.showtempdisplay, self.generalSettings.showrpmdisplay,
                                          self.generalSettings.cp_notice)
	if g_server then
		g_server:broadcastEvent(eventGPS)
		g_server:broadcastEvent(eventGS)
	end
end

function RVBMain:onReadStream(streamId, connection)
	if connection:getIsServer() then
		self.gameplaySettings.dailyServiceInterval = streamReadInt32(streamId)
		self.gameplaySettings.periodicServiceInterval = streamReadInt32(streamId)
		self.gameplaySettings.repairshop = streamReadBool(streamId)
		self.gameplaySettings.workshopOpen = streamReadInt32(streamId)
		self.gameplaySettings.workshopClose = streamReadInt32(streamId)
		self.gameplaySettings.thermostatLifetime = streamReadInt32(streamId)
		self.gameplaySettings.lightingsLifetime = streamReadInt32(streamId)
		self.gameplaySettings.glowplugLifetime = streamReadInt32(streamId)
		self.gameplaySettings.wipersLifetime = streamReadInt32(streamId)
		self.gameplaySettings.generatorLifetime = streamReadInt32(streamId)
		self.gameplaySettings.engineLifetime = streamReadInt32(streamId)
		self.gameplaySettings.selfstarterLifetime = streamReadInt32(streamId)
		self.gameplaySettings.batteryLifetime = streamReadInt32(streamId)
		self.gameplaySettings.tireLifetime = streamReadInt32(streamId)
		
		self.generalSettings.alertmessage = streamReadBool(streamId)
		self.generalSettings.difficulty = streamReadInt32(streamId)
		self.generalSettings.basicrepairtrigger = streamReadBool(streamId)
		self.generalSettings.debugdisplay = streamReadBool(streamId)
		self.generalSettings.showtempdisplay = streamReadBool(streamId)
		self.generalSettings.showrpmdisplay = streamReadBool(streamId)
		self.generalSettings.cp_notice = streamReadBool(streamId)
		
        self:syncSettingsToAllClients()
	end
end

function RVBMain:onWriteStream(streamId, connection)
	if not connection:getIsServer() then
		streamWriteInt32(streamId, self.gameplaySettings.dailyServiceInterval)
		streamWriteInt32(streamId, self.gameplaySettings.periodicServiceInterval)
		streamWriteBool(streamId, self.gameplaySettings.repairshop)
		streamWriteInt32(streamId, self.gameplaySettings.workshopOpen)
		streamWriteInt32(streamId, self.gameplaySettings.workshopClose)
		streamWriteInt32(streamId, self.gameplaySettings.thermostatLifetime)
		streamWriteInt32(streamId, self.gameplaySettings.lightingsLifetime)
		streamWriteInt32(streamId, self.gameplaySettings.glowplugLifetime)
		streamWriteInt32(streamId, self.gameplaySettings.wipersLifetime)
		streamWriteInt32(streamId, self.gameplaySettings.generatorLifetime)
		streamWriteInt32(streamId, self.gameplaySettings.engineLifetime)
		streamWriteInt32(streamId, self.gameplaySettings.selfstarterLifetime)
		streamWriteInt32(streamId, self.gameplaySettings.batteryLifetime)
		streamWriteInt32(streamId, self.gameplaySettings.tireLifetime)
		
		streamWriteBool(streamId, self.generalSettings.alertmessage)
		streamWriteInt32(streamId, self.generalSettings.difficulty)
		streamWriteBool(streamId, self.generalSettings.basicrepairtrigger)
		streamWriteBool(streamId, self.generalSettings.debugdisplay)
		streamWriteBool(streamId, self.generalSettings.showtempdisplay)
		streamWriteBool(streamId, self.generalSettings.showrpmdisplay)
		streamWriteBool(streamId, self.generalSettings.cp_notice)
	end
end